
#ifndef _LINPAC_PDSLIB_H
#define _LINPAC_PDSLIB_H
#include "pds700A.h"

#define Open_Com(PDSMod, ServerIP, CommandPort, ServerCOM, Baudrate, Data, Parity, Stop) Open_ComA(PDSMod, ServerIP, CommandPort, ServerCOM, Baudrate, Data, Parity, Stop)
#define Close_Com(PDSMod, ServerCOM) Close_ComA(PDSMod, ServerCOM)
#define Send_Read_String(PDSMod, ServerCOM, Out_String, In_String) Send_Read_StringA(PDSMod, ServerCOM, Out_String, In_String)
#define Send_String(PDSMod, ServerCOM, Out_String) Send_StringA(PDSMod, ServerCOM, Out_String)
#define Read_String(PDSMod, ServerCOM, In_String) Read_StringA(PDSMod, ServerCOM, In_String)
#define Send_Binary(PDSMod, ServerCOM, Out_String, len) Send_BinaryA(PDSMod, ServerCOM, Out_String, len)
#define Read_Binary(PDSMod, ServerCOM, In_String, len) Read_BinaryA(PDSMod, ServerCOM, In_String, len)
#define Send_Read_Cmd(CMDSfd, Out_String, In_String) Send_Read_CmdA(CMDSfd, Out_String, In_String)
#define Send_Cmd(CMDSfd, Out_String) Send_CmdA(CMDSfd, Out_String)

#endif
